metertools.MetricAccentKernel
=============================

.. abjad-lineage:: abjad.tools.metertools.MetricAccentKernel.MetricAccentKernel

.. autoclass:: abjad.tools.metertools.MetricAccentKernel.MetricAccentKernel

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.metertools.MetricAccentKernel.MetricAccentKernel.count_offsets_in_expr
      ~abjad.tools.metertools.MetricAccentKernel.MetricAccentKernel.kernel
      ~abjad.tools.metertools.MetricAccentKernel.MetricAccentKernel.__call__
      ~abjad.tools.metertools.MetricAccentKernel.MetricAccentKernel.__eq__
      ~abjad.tools.metertools.MetricAccentKernel.MetricAccentKernel.__format__
      ~abjad.tools.metertools.MetricAccentKernel.MetricAccentKernel.__ne__
      ~abjad.tools.metertools.MetricAccentKernel.MetricAccentKernel.__repr__

Bases
-----

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject>`

- :py:class:`__builtin__.object <object>`

Read-only properties
--------------------

.. autoattribute:: abjad.tools.metertools.MetricAccentKernel.MetricAccentKernel.kernel
   :noindex:

Static methods
--------------

.. automethod:: abjad.tools.metertools.MetricAccentKernel.MetricAccentKernel.count_offsets_in_expr
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.metertools.MetricAccentKernel.MetricAccentKernel.__call__
   :noindex:

.. automethod:: abjad.tools.metertools.MetricAccentKernel.MetricAccentKernel.__eq__
   :noindex:

.. automethod:: abjad.tools.metertools.MetricAccentKernel.MetricAccentKernel.__format__
   :noindex:

.. automethod:: abjad.tools.metertools.MetricAccentKernel.MetricAccentKernel.__ne__
   :noindex:

.. automethod:: abjad.tools.metertools.MetricAccentKernel.MetricAccentKernel.__repr__
   :noindex:
